@@ -8,12 +8,13 @@ to type, etc).
 Experiment by changing arg1_topics.py and looking at the output tree 
 in arg1_topics_out.py.
 
-:copyright: Copyright 2006-2009 by Oliver Schoenborn, all rights reserved.
+:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
 :license: BSD, see LICENSE.txt for details.
 '''
 
 from pubsub import setuparg1
 from pubsub import pub
+from pubsub.py2and3 import print_
 
 import notifhandle
 import exchandle
@@ -22,30 +23,29 @@ import arg1_topics
 
 #***** actual application **********
 
-print 'Using "arg1" messaging protocol of pubsub v3'
+print_('Using "arg1" messaging protocol of pubsub v3')
 
 try:
-    print '------- init ----------'
+    print_('------- init ----------')
 
-    pub.importTopicTree( arg1_topics )
+    pub.addTopicDefnProvider( arg1_topics, pub.TOPIC_TREE_FROM_CLASS )
     pub.setTopicUnspecifiedFatal()
 
     import arg1_listeners
     import arg1_senders as senders
 
-    senders.init()
-    print '-----------------------'
+    print_('-----------------------')
     senders.doSomething1()
     senders.doSomething2()
 
-    print '------- done ----------'
+    print_('------- done ----------')
 
-    print 'Exporting topic tree to', arg1_topics.__name__
-    pub.exportTopicTree('arg1_topics_out')
+    print_('Exporting topic tree to', arg1_topics.__name__)
+    pub.exportTopicTreeSpec('arg1_topics_out')
 
-except Exception, exc:
+except Exception:
     import traceback
     traceback.print_exc()
-    print pub.exportTopicTree()
+    print_(pub.exportTopicTreeSpec())
 
-print '------ exiting --------'
\ No newline at end of file
+print_('------ exiting --------')
\ No newline at end of file
